@@ -1,5 +1,5 @@
 # bind global variables
-utils::globalVariables(c("val", "frq", "grp", "upper.ci", "lower.ci", "ia", "..density.."))
+utils::globalVariables(c("val", "frq", "grp", "label.pos", "upper.ci", "lower.ci", "ia", "..density.."))
 
 
 #' @title Plot frequencies of variables
@@ -224,6 +224,7 @@ sjp.frq <- function(varCount,
                     coord.flip = FALSE,
                     vjust = "bottom",
                     hjust = "center",
+                    y.offset = NULL,
                     na.rm = TRUE,
                     printPlot = TRUE) {
   # --------------------------------------------------------
@@ -231,10 +232,50 @@ sjp.frq <- function(varCount,
   # --------------------------------------------------------
   var.name <- get_var_name(deparse(substitute(varCount)))
   # --------------------------------------------------------
+  # set text label offset
+  # --------------------------------------------------------
+  if (is.null(y.offset)) {
+    # get maximum y-pos
+    y.offset <- ceiling(max(table(varCount)) / 100)
+    if (coord.flip) {
+      if (missing(vjust)) vjust <- "center"
+      if (missing(hjust)) hjust <- "bottom"
+      if (hjust == "bottom")
+        y_offset <- y.offset
+      else if (hjust == "top")
+        y_offset <- -y.offset
+      else
+        y_offset <- 0
+    } else {
+      if (vjust == "bottom")
+        y_offset <- y.offset
+      else if (vjust == "top")
+        y_offset <- -y.offset
+      else
+        y_offset <- 0
+    }
+  } else {
+    y_offset <- y.offset
+  }
+  # --------------------------------------------------------
   # try to automatically set labels is not passed as argument
   # --------------------------------------------------------
-  if (is.null(axisLabels.x)) axisLabels.x <- sjmisc::get_labels(varCount, attr.only = F, include.values = NULL, include.non.labelled = T)
-  if (is.null(interactionVarLabels) && !is.null(interactionVar)) interactionVarLabels <- sjmisc::get_labels(interactionVar, attr.only = F, include.values = NULL, include.non.labelled = T)
+  if (is.null(axisLabels.x)) {
+    axisLabels.x <- sjmisc::get_labels(
+      varCount,
+      attr.only = F,
+      include.values = NULL,
+      include.non.labelled = T
+    )
+  }
+  if (is.null(interactionVarLabels) && !is.null(interactionVar)) {
+    interactionVarLabels <- sjmisc::get_labels(
+      interactionVar,
+      attr.only = F,
+      include.values = NULL,
+      include.non.labelled = T
+    )
+  }
   if (is.null(axisTitle.x)) axisTitle.x <- sjmisc::get_label(varCount, def.value = var.name)
   if (is.null(title)) title <- sjmisc::get_label(varCount, def.value = var.name)
   # --------------------------------------------------------
@@ -245,9 +286,7 @@ sjp.frq <- function(varCount,
   # --------------------------------------------------------
   # check color argument
   # --------------------------------------------------------
-  if (length(geom.colors) > 1) {
-    geom.colors <- geom.colors[1]
-  }
+  if (length(geom.colors) > 1) geom.colors <- geom.colors[1]
   # --------------------------------------------------------
   # We have several options to name the plot type
   # Here we will reduce it to a unique value
@@ -271,7 +310,7 @@ sjp.frq <- function(varCount,
     if (type == "bars") 
       geom.size <- .7
     else if (type == "dots") 
-      geom.size <- 3
+      geom.size <- 2.5
     else if (type == "histogram") 
       geom.size <- .7
     else if (type == "line") 
@@ -287,7 +326,7 @@ sjp.frq <- function(varCount,
   # check whether variable should be auto-grouped
   #---------------------------------------------------
   if (!is.null(interactionVar) && type != "boxplots" && type != "violin") {
-    warning("'interactionVar' only applies to boxplots and violinplots (see 'type') and will be ignored.", call. = F)
+    warning("`interactionVar` only applies to boxplots and violinplots (see `type`) and will be ignored.", call. = F)
     interactionVar <- NULL
   }
   #---------------------------------------------------
@@ -323,6 +362,13 @@ sjp.frq <- function(varCount,
   mydat <- df.frq$mydat
   if (!is.null(df.frq$labels) && is.null(axisLabels.x)) axisLabels.x <- df.frq$labels
   # --------------------------------------------------------
+  # define text label position
+  # --------------------------------------------------------
+  if (showCI)
+    mydat$label.pos <- mydat$upper.ci
+  else
+    mydat$label.pos <- mydat$frq
+  # --------------------------------------------------------
   # Trim labels and title to appropriate size
   # --------------------------------------------------------
   # check length of diagram title and split longer string at into new lines
@@ -435,58 +481,28 @@ sjp.frq <- function(varCount,
     # here we have counts and percentages
     if (showPercentageValues && showCountValues) {
       if (coord.flip) {
-        if (showCI) {
-          ggvaluelabels <-  geom_text(label = sprintf("%i (%.01f%%)", mydat$frq, mydat$valid.prc),
-                                      hjust = hjust,
-                                      vjust = vjust,
-                                      aes(y = upper.ci))
-        } else {
-          ggvaluelabels <-  geom_text(label = sprintf("%i (%.01f%%)", mydat$frq, mydat$valid.prc),
-                                      hjust = hjust,
-                                      vjust = vjust,
-                                      aes(y = frq))
-        }
+        ggvaluelabels <-  geom_text(label = sprintf("%i (%.01f%%)", mydat$frq, mydat$valid.prc),
+                                    hjust = hjust,
+                                    vjust = vjust,
+                                    aes(y = label.pos + y_offset))
       } else {
-        if (showCI) {
-          ggvaluelabels <-  geom_text(label = sprintf("%i\n(%.01f%%)", mydat$frq, mydat$valid.prc),
-                                      hjust = hjust,
-                                      vjust = vjust,
-                                      aes(y = upper.ci))
-        } else {
-          ggvaluelabels <-  geom_text(label = sprintf("%i\n(%.01f%%)", mydat$frq, mydat$valid.prc),
-                                      hjust = hjust,
-                                      vjust = vjust,
-                                      aes(y = frq))
-        }
+        ggvaluelabels <-  geom_text(label = sprintf("%i\n(%.01f%%)", mydat$frq, mydat$valid.prc),
+                                    hjust = hjust,
+                                    vjust = vjust,
+                                    aes(y = label.pos + y_offset))
       }
     } else if (showCountValues) {
-      if (showCI) {
-        # here we have counts, without percentages
-        ggvaluelabels <-  geom_text(label = sprintf("%i", mydat$frq),
-                                    hjust = hjust,
-                                    vjust = vjust,
-                                    aes(y = upper.ci))
-      } else {
-        # here we have counts, without percentages
-        ggvaluelabels <-  geom_text(label = sprintf("%i", mydat$frq),
-                                    hjust = hjust,
-                                    vjust = vjust,
-                                    aes(y = frq))
-      }
+      # here we have counts, without percentages
+      ggvaluelabels <-  geom_text(label = sprintf("%i", mydat$frq),
+                                  hjust = hjust,
+                                  vjust = vjust,
+                                  aes(y = label.pos + y_offset))
     } else if (showPercentageValues) {
-      if (showCI) {
-        # here we have counts, without percentages
-        ggvaluelabels <-  geom_text(label = sprintf("%.01f%%", mydat$valid.prc),
-                                    hjust = hjust,
-                                    vjust = vjust,
-                                    aes(y = upper.ci))
-      } else {
-        # here we have counts, without percentages
-        ggvaluelabels <-  geom_text(label = sprintf("%.01f%%", mydat$valid.prc),
-                                    hjust = hjust,
-                                    vjust = vjust,
-                                    aes(y = frq))
-      }
+      # here we have counts, without percentages
+      ggvaluelabels <-  geom_text(label = sprintf("%.01f%%", mydat$valid.prc),
+                                  hjust = hjust,
+                                  vjust = vjust,
+                                  aes(y = label.pos + y_offset))
     } else {
       # no labels
       ggvaluelabels <-  geom_text(aes(y = frq), label = "")
@@ -546,7 +562,7 @@ sjp.frq <- function(varCount,
                        width = geom.size, 
                        fill = geom.colors)
     } else if (type == "dots") {
-      geob <- geom_point(size = geom.size, fill = geom.colors)
+      geob <- geom_point(size = geom.size, colour = geom.colors)
     }
     # -----------------------------------
     # mydat is a data frame that only contains one variable (var).
@@ -656,7 +672,7 @@ sjp.frq <- function(varCount,
     # -----------------------------------------------------------------
     if (type == "histogram") {
       xv <- stats::na.omit(varCount)
-      if (geom.size < round(diff(range(xv)) / 50)) message("Using very small binwidth. Consider adjusting \"geom.size\" argument.")
+      if (geom.size < round(diff(range(xv)) / 50)) message("Using very small binwidth. Consider adjusting `geom.size` argument.")
       hist.dat <- data.frame(xv)
       baseplot <- ggplot(mydat) +
         geom_histogram(data = hist.dat,
@@ -705,9 +721,10 @@ sjp.frq <- function(varCount,
                    x = mittelwert, 
                    y = upper_lim, 
                    parse = TRUE, 
-                   label = paste("italic(bar(x)) == ", "'", c(round(mittelwert, 1)), "'"), 
-                   hjust = 1.1, 
-                   vjust = 2.2)
+                   label = paste("italic(bar(x)) == ", round(mittelwert, 1),
+                                 "~~italic(s) == ", round(stddev, 1)),
+                   vjust = "top",
+                   hjust = "top")
       }
       # check whether the user wants to plot standard deviation area
       if (showStandardDeviation) {
@@ -729,18 +746,6 @@ sjp.frq <- function(varCount,
                      linetype = 3, 
                      size = meanInterceptLineSize, 
                      alpha = 0.7)
-        # if mean values are plotted, plot standard deviation values as well
-        if (showMeanValue) {
-          baseplot <- baseplot + 
-            # use annotation instead of geomtext, because we need mean value only printed once
-            annotate("text", 
-                     x = mittelwert, 
-                     y = upper_lim, 
-                     label = sprintf("italic(s) == %.2f", round(stddev, 1)), 
-                     parse = TRUE, 
-                     hjust = 1.15, 
-                     vjust = 4.2)
-        }
       }
     }
     # show absolute and percentage value of each bar.
