@@ -61,7 +61,7 @@ sjp.gpt <- function(x,
                     y,
                     groups,
                     geom.colors = "Set1",
-                    geom.size = 4,
+                    geom.size = 2.5,
                     shape.fill.color = "#f0f0f0",
                     shapes = c(15, 16, 17, 18, 21, 22, 23, 24, 25, 7, 8, 9, 10, 12),
                     title = NULL,
