@@ -106,6 +106,7 @@
 #'                   css.arc = "color:blue;"))}
 #'
 #' @importFrom utils txtProgressBar setTxtProgressBar
+#' @importFrom psych describe
 #' @export
 sjt.df <- function(mydf,
                    describe = TRUE,
@@ -144,7 +145,7 @@ sjt.df <- function(mydf,
     missings <- apply(mydf, 2, function(x) sum(is.na(x)))
     # and proportion of missings
     missings.percentage <- round(100 * missings / nrow(mydf), 2)
-    mydf <- round(describe(mydf), 2)
+    mydf <- round(psych::describe(mydf), 2)
     # insert missing variables in data frame
     mydf <- data.frame(mydf[, 1:2], 
                        missings, 
@@ -158,8 +159,8 @@ sjt.df <- function(mydf,
                                   function(x)
                                     if (max(x, na.rm = T) > 999)
                                       prettyNum(x, big.mark = ",")
-                                  else
-                                    x))
+                                    else
+                                      x))
     }
   }
   # -------------------------------------
