@@ -1,4 +1,6 @@
 library(testthat)
 library(sjPlot)
+library(sjmisc)
+data(efc)
 
 test_check("sjPlot")
